Clazz.declarePackage("J.translation");
(function(){
var c$ = Clazz.declareType(J.translation, "PO", null);
})();
;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
